@@ -174,7 +174,9 @@ fr_command_iso_extract (FrCommand  *comm,
 	for (scan = file_list; scan; scan = scan->next) {
 		char       *path = scan->data;
 		const char *filename;
-		char       *file_dir, *e_temp_dest_dir = NULL, *temp_dest_dir = NULL;
+		char       *file_dir;
+		char       *e_temp_dest_dir = NULL;
+		char       *temp_dest_dir = NULL;
 
 		filename = file_name_from_path (path);
 		file_dir = remove_level_from_path (path);
@@ -188,7 +190,7 @@ fr_command_iso_extract (FrCommand  *comm,
 			continue;
 
 		temp_dest_dir = unescape_str (e_temp_dest_dir);
-		ensure_dir_exists (temp_dest_dir, 0700);
+		make_directory_tree_from_path (temp_dest_dir, 0700, NULL);
 
 		fr_process_begin_command (comm->process, "sh " PRIVEXECDIR "isoinfo.sh");
 		fr_process_set_working_dir (comm->process, temp_dest_dir);
@@ -211,6 +213,18 @@ fr_command_iso_extract (FrCommand  *comm,
 }
 
 
+static void
+fr_command_iso_set_mime_type (FrCommand  *comm,
+		 	      const char *mime_type)
+{
+	FR_COMMAND_CLASS (parent_class)->set_mime_type (comm, mime_type);
+	
+	comm->capabilities |= FR_COMMAND_CAP_ARCHIVE_MANY_FILES;
+	if (is_program_in_path ("isoinfo")) 
+		comm->capabilities |= FR_COMMAND_CAP_READ;
+}
+
+
 static void
 fr_command_iso_class_init (FrCommandIsoClass *class)
 {
@@ -222,8 +236,9 @@ fr_command_iso_class_init (FrCommandIsoClass *class)
 
 	gobject_class->finalize = fr_command_iso_finalize;
 
-	afc->list    = fr_command_iso_list;
-	afc->extract = fr_command_iso_extract;
+	afc->list           = fr_command_iso_list;
+	afc->extract        = fr_command_iso_extract;
+	afc->set_mime_type  = fr_command_iso_set_mime_type;
 }
 
 
@@ -232,8 +247,6 @@ fr_command_iso_init (FrCommand *comm)
 {
 	FrCommandIso *comm_iso = FR_COMMAND_ISO (comm);
 
-	comm->file_type = FR_FILE_TYPE_ISO;
-
 	comm_iso->cur_path = NULL;
 	comm_iso->joliet = TRUE;
 
@@ -294,20 +307,3 @@ fr_command_iso_get_type ()
 
 	return type;
 }
-
-
-FrCommand *
-fr_command_iso_new (FrProcess  *process,
-		    const char *filename)
-{
-	FrCommand *comm;
-
-	if (! is_program_in_path ("isoinfo")) {
-		return NULL;
-	}
-
-	comm = FR_COMMAND (g_object_new (FR_TYPE_COMMAND_ISO, NULL));
-	fr_command_construct (comm, process, filename);
-
-	return comm;
-}
